@@ -11,6 +11,15 @@ import sys
 import tempfile
 import progressbar
 
+def mkdir_p(path):
+    try:
+        os.makedirs(path)
+    except OSError as exc: # Python >2.5
+        if exc.errno == errno.EEXIST and os.path.isdir(path):
+            pass
+        else:
+            raise
+
 def transfer_callback(name):
     def inner(size, total):
         widgets = ['{}: '.format(name), progressbar.Percentage(), ' ', progressbar.Bar()]
@@ -32,7 +41,7 @@ def sync():
     conn = boto.connect_s3(access_key_id, secret_access_key)
     bucket = boto.s3.bucket.Bucket(conn, bucket_name)
     git_directory = g.rev_parse(git_dir=True)
-    destination_folder = os.path.join(git_directory, "storage/objects")
+    destination_folder = os.path.join(git_directory, "bigstore/objects")
 
     lines = g.ls_tree('HEAD', l=True, z=True, r=True).split('\x00')
     for line in lines:
@@ -71,28 +80,18 @@ def filter_clean():
     thirty_two_hex = re.compile(r'^bigfile\$[a-f0-9]{32}')
 
     def clean_file(hash, file):
-        sys.stderr.write("cleaning file\n")
         hexdigest = hash.hexdigest()
         filename = file.name
         file.close()
 
         g = Git('.')
         git_directory = g.rev_parse(git_dir=True)
-        destination_folder = os.path.join(git_directory, "storage/objects")
+        destination_folder = os.path.join(git_directory, "bigstore/objects")
         mkdir_p(destination_folder)
         destination_filename = os.path.join(destination_folder, hexdigest)
         shutil.copy(filename, destination_filename)
         sys.stdout.write("bigfile${}".format(hexdigest))
 
-    def mkdir_p(path):
-        try:
-            os.makedirs(path)
-        except OSError as exc: # Python >2.5
-            if exc.errno == errno.EEXIST and os.path.isdir(path):
-                pass
-            else:
-                raise
-
     file = tempfile.NamedTemporaryFile(mode='w+t', delete=False)
     hash = hashlib.md5()
     for line in sys.stdin:
@@ -105,7 +104,6 @@ def filter_clean():
     if file_length == 40:
         contents = file.read()
         if thirty_two_hex.match(contents):
-            sys.stderr.write("file already cleaned: {}\n".format(contents))
             sys.stdout.write(contents)
             sys.exit(0)
 
@@ -120,11 +118,10 @@ def filter_smudge():
 
     if thirty_two_hex.match(contents):
         _, hexdigest = contents.split('$')
-        source_filename = os.path.join(git_directory, "storage/objects", hexdigest)
+        source_filename = os.path.join(git_directory, "bigstore/objects", hexdigest)
         try:
             file = open(source_filename, 'rb')
         except IOError:
-            sys.stderr.write("couldn't find file, saving placeholder \n")
             sys.stdout.write(contents)
         else:
             for line in file:
